Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(931)

Unified Diff: tests/language/call_nonexistent_constructor_test.dart

Issue 10909166: Rename NoSuchMethodException to NoSuchMethodError. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Address review comments Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tests/language/bad_named_parameters_test.dart ('k') | tests/language/call_nonexistent_static_test.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tests/language/call_nonexistent_constructor_test.dart
diff --git a/tests/language/call_nonexistent_constructor_test.dart b/tests/language/call_nonexistent_constructor_test.dart
index 4f03e4a2e3ad6b8bbc68705ea632d8745d1851a0..f0f066873c3a1970221c7657f5221bd1136b41b4 100644
--- a/tests/language/call_nonexistent_constructor_test.dart
+++ b/tests/language/call_nonexistent_constructor_test.dart
@@ -3,7 +3,7 @@
// BSD-style license that can be found in the LICENSE file.
// When attempting to call a nonexistent constructor, check that a
// NoSuchMethodException is thrown.
foo() {
throw 'hest';
@@ -24,7 +24,7 @@ main() {
Expect.equals(1, i);
try {
new A();
- } on NoSuchMethodException catch (e) {
+ } on NoSuchMethodError catch (e) {
i = 2;
}
Expect.equals(2, i);
@@ -3,7 +3,7 @@
// BSD-style license that can be found in the LICENSE file.
// When attempting to call a nonexistent constructor, check that a
-// NoSuchMethodException is thrown.
+// NoSuchMethodError is thrown.
foo() {
throw 'hest';
« no previous file with comments | « tests/language/bad_named_parameters_test.dart ('k') | tests/language/call_nonexistent_static_test.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698